==> img0ch-2.1.10.zip: img0ch/_template/type/t_form.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?cs var:html_escape(BBS_TITLE) ?>̃Xbh쐬tH[</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js?v=?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript">
//<![CDATA[
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
//]]>
</script>
<style type="text/css">
/*
<![CDATA[
*/
fieldset { border: 0px; }
img { border: 0px; }
.center { text-align:center !important;  }
.clear { clear: both !important; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
.right { text-align: right !important; }
.res_body { margin-left: 40px; }
/* ]]> */
</style>
<?cs var:META ?>
</head>
<body>

<div class="center" id="top">
<?cs if:BBS_TITLE_PICTURE ?>
 <?cs if:BBS_TITLE_LINK ?>
  <a href="<?cs var:html_escape(BBS_TITLE_LINK) ?>">
   <img src="<?cs var:html_escape(BBS_TITLE_PICTURE) ?>" alt="<?cs var:html_escape(BBS_TITLE) ?>̊Ŕ" />
  </a>
 <?cs else ?>
  <img src="<?cs var:html_escape(BBS_TITLE_PICTURE) ?>" alt="<?cs var:html_escape(BBS_TITLE) ?>̊Ŕ" />
 <?cs /if ?>
<?cs /if ?>
</div>

<div class="day" id="info">
 <h2><span class="title"><?cs var:html_escape(BBS_SUBTITLE) ?></span></h2>
 <div class="body">
  <div class="section">
   <?cs var:HEAD ?>
  </div>
 </div>
</div>

<?cs if:Banner ?>
<hr class="sep" />
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<?cs /if ?>

<hr class="sep" />

<div class="day" id="thread_builder_form">
 <h2><span class="title">XbhVK쐬</span></h2>
 <div class="form">
  <form class="comment" method="post" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
   <div class="hidden_field">
    <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
    <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>" />
   </div>
   <div class="textarea">
    ^CgF<input type="text" name="subject" size="25" />
   </div>
   <div class="field name">
    OF<input type="text" name="FROM" size="19" />
   </div>
   <div class="field mail">
    E-mailF<input type="text" name="mail" size="19" />
   </div>
   <?cs if:UploadableFromThread ?>
    <div class="field name">
     <br />摜F<input type="file" name="file" />
    </div>
    <div class="field mail">
     폜pXF<input type="password" name="pass" />
    </div>
   <?cs /if ?>
   <div class="textarea">
    RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
   </div>
   <div class="button">
    <input type="submit" name="submit" value="VKXbh쐬" />
   </div>
  </form>
 </div>
</div>

<hr class="sep" />

<div class="footer">
 <?cs var:FOOT ?>
</div>

</body>
</html>

==> img0ch-3.0.0.zip: img0ch/_template/type/t_form.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?cs var:html_escape(BBS_TITLE) ?>̃Xbh쐬tH[</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
<script type="text/javascript">
//<![CDATA[
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
//]]>
</script>
<style type="text/css">
/*
<![CDATA[
*/
fieldset { border: 0px; }
img { border: 0px; }
.center { text-align:center !important;  }
.clear { clear: both !important; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
.right { text-align: right !important; }
.res_body { margin-left: 40px; }
/* ]]> */
</style>
<?cs var:META ?>
</head>
<body>

<div class="center" id="top">
<?cs if:BBS_TITLE_PICTURE ?>
 <?cs if:BBS_TITLE_LINK ?>
  <a href="<?cs var:html_escape(BBS_TITLE_LINK) ?>">
   <img src="<?cs var:html_escape(BBS_TITLE_PICTURE) ?>" alt="<?cs var:html_escape(BBS_TITLE) ?>̊Ŕ" />
  </a>
 <?cs else ?>
  <img src="<?cs var:html_escape(BBS_TITLE_PICTURE) ?>" alt="<?cs var:html_escape(BBS_TITLE) ?>̊Ŕ" />
 <?cs /if ?>
<?cs /if ?>
</div>

<div class="day" id="info">
 <h2><span class="title"><?cs var:html_escape(BBS_SUBTITLE) ?></span></h2>
 <div class="body">
  <div class="section">
   <?cs var:HEAD ?>
  </div>
 </div>
</div>

<?cs if:Banner ?>
<hr class="sep" />
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<?cs /if ?>

<hr class="sep" />

<div class="day" id="thread_builder_form">
 <h2><span class="title">XbhVK쐬</span></h2>
 <div class="form">
  <form class="comment" method="post" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
   <div class="hidden_field">
    <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
    <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>" />
   </div>
   <div class="textarea">
    ^CgF<input type="text" name="subject" size="25" />
   </div>
   <div>
    <div class="field name">
     OF<input type="text" name="FROM" size="19" />
    </div>
    <div class="field mail">
     E-mailF<input type="text" name="mail" size="19" />
    </div>
   </div>
   <?cs if:UploadableFromThread ?>
   <div>
    <div class="field name">
     摜F<input type="file" name="file" />
    </div>
    <div class="field mail">
     폜pXF<input type="password" name="pass" />
    </div>
   </div>
   <?cs /if ?>
   <?cs if:Icon ?>
   <div class="textarea">
    ACRF<select name="icon"><option value="" selected="selected">Ȃ</option>
    <?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
    <?cs /each ?></select>
   </div>
   <?cs /if ?>
   <div class="textarea">
    RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
   </div>
   <div class="button">
    <input type="submit" name="submit" value="VKXbh쐬" />
   </div>
  </form>
 </div>
</div>

<hr class="sep" />

<div class="footer">
 <?cs var:FOOT ?>
</div>

</body>
</html>
